@@ -30,6 +30,13 @@ from conf import TIMEOUT
 from conf import UDS_PATH
 
 
+def maybe_decode(data):
+    if isinstance(data, bytes):
+        return data.decode('ascii')
+    else:
+        return data
+
+
 @pytest.yield_fixture
 def redis_server(scope='module'):
     try:
@@ -42,14 +49,16 @@ def redis_server(scope='module'):
             yield process
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope='function', params=[True, False], ids=['decode_responses=True', 'decode_responses=False'])
 def make_conn(request, redis_server):
     """Redis connection factory."""
+
     def make_conn_factory():
-        conn_ = StrictRedis(unix_socket_path=UDS_PATH)
+        conn_ = StrictRedis(unix_socket_path=UDS_PATH, decode_responses=request.param)
         request.addfinalizer(conn_.flushdb)
 
         return conn_
+
     return make_conn_factory
 
 
@@ -63,6 +72,7 @@ def make_process(request):
     """Process factory, that makes processes, that terminate themselves
     after a test run.
     """
+
     def make_process_factory(*args, **kwargs):
         process = multiprocessing.Process(*args, **kwargs)
         request.addfinalizer(process.terminate)
@@ -103,7 +113,7 @@ def test_no_block(conn):
 def test_timeout(conn):
     with Lock(conn, "foobar"):
         lock = Lock(conn, "foobar")
-        assert lock.acquire(timeout=1) == False
+        assert lock.acquire(timeout=1) is False
 
 
 def test_timeout_expire(conn):
@@ -116,7 +126,7 @@ def test_timeout_expire(conn):
 def test_timeout_expire_with_renewal(conn):
     with Lock(conn, "foobar", expire=1, auto_renewal=True):
         lock = Lock(conn, "foobar")
-        assert lock.acquire(timeout=2) == False
+        assert lock.acquire(timeout=2) is False
 
 
 def test_timeout_acquired(conn):
@@ -155,7 +165,7 @@ def test_invalid_timeout(conn):
 
 
 def test_expire(conn):
-    lock = Lock(conn, "foobar", expire=TIMEOUT/4)
+    lock = Lock(conn, "foobar", expire=TIMEOUT / 4)
     lock.acquire()
     with TestProcess(sys.executable, HELPER, 'test_expire') as proc:
         with dump_on_error(proc.read):
@@ -170,7 +180,7 @@ def test_expire(conn):
             )
     lock = Lock(conn, "foobar")
     try:
-        assert lock.acquire(blocking=False) == True
+        assert lock.acquire(blocking=False) is True
     finally:
         lock.release()
 
@@ -277,11 +287,11 @@ def test_no_overlap(redis_server):
     with TestProcess(sys.executable, HELPER, 'test_no_overlap') as proc:
         with dump_on_error(proc.read):
             name = 'lock:foobar'
-            wait_for_strings(proc.read, 10*TIMEOUT, 'Getting %r ...' % name)
-            wait_for_strings(proc.read, 10*TIMEOUT, 'Got lock for %r.' % name)
-            wait_for_strings(proc.read, 10*TIMEOUT, 'Releasing %r.' % name)
-            wait_for_strings(proc.read, 10*TIMEOUT, 'UNLOCK_SCRIPT not cached.')
-            wait_for_strings(proc.read, 10*TIMEOUT, 'DIED.')
+            wait_for_strings(proc.read, 10 * TIMEOUT, 'Getting %r ...' % name)
+            wait_for_strings(proc.read, 10 * TIMEOUT, 'Got lock for %r.' % name)
+            wait_for_strings(proc.read, 10 * TIMEOUT, 'Releasing %r.' % name)
+            wait_for_strings(proc.read, 10 * TIMEOUT, 'UNLOCK_SCRIPT not cached.')
+            wait_for_strings(proc.read, 10 * TIMEOUT, 'DIED.')
 
             class Event(object):
                 pid = start = end = '?'
@@ -310,22 +320,25 @@ def test_no_overlap(redis_server):
                 for other in events.values():
                     if other is not event:
                         try:
-                            if other.start < event.start < other.end or \
-                               other.start < event.end < other.end:
+                            if (
+                                other.start < event.start < other.end or
+                                other.start < event.end < other.end
+                            ):
                                 pytest.fail('%s overlaps %s' % (event, other))
-                        except:
+                        except Exception:
                             print("[%s/%s]" % (event, other))
                             raise
 
 
 NWORKERS = 125
 
+
 @pytest.mark.skipif(platform.python_implementation() == 'PyPy', reason="This appears to be way too slow to run on PyPy")
 def test_no_overlap2(make_process, make_conn):
     """The second version of contention test, that uses multiprocessing."""
-    go         = multiprocessing.Event()
+    go = multiprocessing.Event()
     count_lock = multiprocessing.Lock()
-    count      = multiprocessing.Value('H', 0)
+    count = multiprocessing.Value('H', 0)
 
     def workerfn(go, count_lock, count):
         redis_lock = Lock(make_conn(), 'lock')
@@ -381,8 +394,8 @@ def test_reset_all(conn):
 
 
 def test_owner_id(conn):
-    unique_identifier = b"foobar-identifier"
-    lock = Lock(conn, "foobar-tok", expire=TIMEOUT/4, id=unique_identifier)
+    unique_identifier = "foobar-identifier"
+    lock = Lock(conn, "foobar-tok", expire=TIMEOUT / 4, id=unique_identifier)
     lock_id = lock.id
     assert lock_id == unique_identifier
 
@@ -399,7 +412,7 @@ def test_token(conn):
     tok = lock.id
     assert conn.get(lock._name) is None
     lock.acquire(blocking=False)
-    assert conn.get(lock._name) == tok
+    assert maybe_decode(conn.get(lock._name)) == tok
 
 
 def test_bogus_release(conn):
@@ -432,7 +445,7 @@ def test_auto_renewal(conn):
     assert lock._lock_renewal_interval == 2
 
     time.sleep(3)
-    assert conn.get(lock._name) == lock.id, "Key expired but it should have been getting renewed"
+    assert maybe_decode(conn.get(lock._name)) == lock.id, "Key expired but it should have been getting renewed"
 
     lock.release()
     assert lock._lock_renewal_thread is None
@@ -468,6 +481,7 @@ def test_signal_cleanup_on_reset_all(conn):
 def test_reset_signalizes(make_conn, make_process):
     """Call to reset() causes LPUSH to signal key, so blocked waiters
     become unblocked."""
+
     def workerfn(unblocked):
         conn = make_conn()
         lock = Lock(conn, 'lock')
@@ -491,6 +505,7 @@ def test_reset_signalizes(make_conn, make_process):
 def test_reset_all_signalizes(make_conn, make_process):
     """Call to reset_all() causes LPUSH to all signal keys, so blocked waiters
     become unblocked."""
+
     def workerfn(unblocked):
         conn = make_conn()
         lock1 = Lock(conn, 'lock1')
